@@ -838,3 +838,15 @@ class VariableOsPython(ReadonlyVariable):
             getInstalledAtom("dev-lang/python",prefix=chroot_path),
             reverse=True):
             return "python{SLOT}".format(**atom)
+
+class VariableClTemplatesWrongPatch(Variable):
+    """
+    Действие выполняемое в случае если патч в EBUILD_PHASE=configure не подходит
+    """
+    type = "choice"
+
+    value = "break"
+
+    def choice(self):
+        return [("warning", _("Show warning")),
+                ("break", _("Break package building"))]
